@@ -22,7 +22,7 @@
 #endif
 
 #ifndef QCORONETWORK_DEPRECATED
-#  define QCORONETWORK_DEPRECATED 
+#  define QCORONETWORK_DEPRECATED __attribute__ ((__deprecated__))
 #endif
 
 #ifndef QCORONETWORK_DEPRECATED_EXPORT
