@@ -22,7 +22,7 @@
 #endif
 
 #ifndef QCOROWEBSOCKETS_DEPRECATED
-#  define QCOROWEBSOCKETS_DEPRECATED 
+#  define QCOROWEBSOCKETS_DEPRECATED __attribute__ ((__deprecated__))
 #endif
 
 #ifndef QCOROWEBSOCKETS_DEPRECATED_EXPORT
